@@ -38,9 +38,6 @@ from imp import find_module, load_module, C_BUILTIN, PY_COMPILED, PKG_DIRECTORY
 from distutils.sysconfig import get_config_var, get_python_lib, get_python_version
 from distutils.errors import DistutilsPlatformError
 
-from six import PY3
-from six.moves import map, range
-
 try:
     import zipimport
 except ImportError:
@@ -49,6 +46,7 @@ except ImportError:
 ZIPFILE = object()
 
 from logilab.common import STD_BLACKLIST, _handle_blacklist
+from logilab.common.deprecation import deprecated
 
 # Notes about STD_LIB_DIR
 # Consider arch-specific installation for STD_LIB_DIR definition
@@ -225,17 +223,12 @@ def _canonicalize_path(path):
     return realpath(expanduser(path))
 
 
-def _path_from_filename(filename):
-    if PY3:
-        return filename
-    else:
-        if filename.endswith(".pyc"):
-            return filename[:-1]
-        return filename
-
 
+@deprecated('you should avoid using modpath_from_file()')
 def modpath_from_file(filename, extrapath=None):
-    """given a file path return the corresponding splitted module's name
+    """DEPRECATED: doens't play well with symlinks and sys.meta_path
+
+    Given a file path return the corresponding splitted module's name
     (i.e name of a module or package splitted on '.')
 
     :type filename: str
@@ -254,7 +247,6 @@ def modpath_from_file(filename, extrapath=None):
     :rtype: list(str)
     :return: the corresponding splitted module's name
     """
-    filename = _path_from_filename(filename)
     filename = _canonicalize_path(filename)
     base = os.path.splitext(filename)[0]
 
@@ -493,6 +485,18 @@ def cleanup_sys_modules(directories):
     return cleaned
 
 
+def clean_sys_modules(names):
+    """remove submodules starting with name from `names` from `sys.modules`"""
+    cleaned = set()
+    for modname in list(sys.modules):
+        for name in names:
+            if modname.startswith(name):
+                del sys.modules[modname]
+                cleaned.add(modname)
+                break
+    return cleaned
+
+
 def is_python_source(filename):
     """
     rtype: bool
