@@ -56,10 +56,10 @@ from shutil import rmtree
 from operator import itemgetter
 from inspect import isgeneratorfunction
 
-from six import string_types
-from six.moves import builtins, range, configparser, input
+import builtins
+import configparser
 
-from logilab.common.deprecation import deprecated
+from logilab.common.deprecation import class_deprecated, deprecated
 
 import unittest as unittest_legacy
 if not getattr(unittest_legacy, "__package__", None):
@@ -90,6 +90,7 @@ is_generator = deprecated('[lgc 0.63] use inspect.isgeneratorfunction')(isgenera
 __unittest = 1
 
 
+@deprecated('with_tempdir is deprecated, use tempfile.TemporaryDirectory.')
 def with_tempdir(callable):
     """A decorator ensuring no temporary file left when the function return
     Work only for temporary file created with the tempfile module"""
@@ -302,7 +303,7 @@ class Tags(set):
         if kwargs:
            raise TypeError("%s are an invalid keyword argument for this function" % kwargs.keys())
 
-        if len(tags) == 1 and not isinstance(tags[0], string_types):
+        if len(tags) == 1 and not isinstance(tags[0], str):
             tags = tags[0]
         super(Tags, self).__init__(tags, **kwargs)
 
@@ -548,11 +549,12 @@ class DocTestFinder(doctest.DocTestFinder):
                                                globs, source_lines)
 
 
-class DocTest(TestCase):
+class DocTest(TestCase, metaclass=class_deprecated):
     """trigger module doctest
     I don't know how to make unittest.main consider the DocTestSuite instance
     without this hack
     """
+    __deprecation_warning__ = 'use stdlib doctest module with unittest API directly'
     skipped = ()
     def __call__(self, result=None, runcondition=None, options=None):\
         # pylint: disable=W0613
